@@ -1,13 +1,13 @@
 //! To parse MySQL's INFORMATION_SCHEMA
 
 mod column;
-mod constraint;
+mod foreign_key;
 mod index;
 mod system;
 mod table;
 
 pub use column::*;
-pub use constraint::*;
+pub use foreign_key::*;
 pub use index::*;
 pub use system::*;
 pub use table::*;
