@@ -1,7 +1,6 @@
-use crate::postgres::def::{ArbitraryPrecisionNumericAttr, ColumnInfo, Type};
-use core::num;
-use sea_query::{escape_string, Alias, ColumnDef, Iden};
-use std::{default, fmt::Write};
+use crate::postgres::def::{ColumnInfo, Type};
+use sea_query::{Alias, ColumnDef, IntervalField};
+use std::{convert::TryFrom, fmt::Write};
 
 impl ColumnInfo {
     pub fn write(&self) -> ColumnDef {
@@ -130,7 +129,14 @@ impl ColumnInfo {
                     None => col_def.time(),
                 };
             }
-            Type::Interval(time_attr) => {}
+            Type::Interval(interval_attr) => {
+                let field = match &interval_attr.field {
+                    Some(field) => IntervalField::try_from(field).ok(),
+                    None => None,
+                };
+                let precision = interval_attr.precision.map(Into::into);
+                col_def.interval(field, precision);
+            }
             Type::Boolean => {
                 col_def.boolean();
             }
@@ -150,7 +156,7 @@ impl ColumnInfo {
                 col_def.custom(Alias::new("path"));
             }
             Type::Polygon => {
-                col_def.custom(Alias::new("ploygon"));
+                col_def.custom(Alias::new("polygon"));
             }
             Type::Circle => {
                 col_def.custom(Alias::new("circle"));
@@ -169,13 +175,13 @@ impl ColumnInfo {
             }
             Type::Bit(bit_attr) => {
                 let mut str = String::new();
-                write!(str, "bit");
+                write!(str, "bit").unwrap();
                 if bit_attr.length.is_some() {
-                    write!(str, "(");
+                    write!(str, "(").unwrap();
                     if let Some(length) = bit_attr.length {
-                        write!(str, "{}", length);
+                        write!(str, "{}", length).unwrap();
                     }
-                    write!(str, ")");
+                    write!(str, ")").unwrap();
                 }
                 col_def.custom(Alias::new(&str));
             }
@@ -221,6 +227,9 @@ impl ColumnInfo {
             Type::Unknown(s) => {
                 col_def.custom(Alias::new(s));
             }
+            Type::Enum(enum_def) => {
+                col_def.enumeration(&enum_def.typename, &enum_def.values);
+            }
         };
         col_def
     }
